==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/storebin_001/StoreBin.java <==

package net.datastream.schemas.mp_entities.storebin_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STOREBINID;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREBINID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORSTOCK" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORHELDITEMS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "storebinid",
    "forstock",
    "forhelditems",
    "outofservice"
})
@XmlRootElement(name = "StoreBin")
public class StoreBin {

    @XmlElement(name = "STOREBINID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREBINID storebinid;
    @XmlElement(name = "FORSTOCK", namespace = "http://schemas.datastream.net/MP_fields")
    protected String forstock;
    @XmlElement(name = "FORHELDITEMS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String forhelditems;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété storebinid.
     * 
     * @return
     *     possible object is
     *     {@link STOREBINID }
     *     
     */
    public STOREBINID getSTOREBINID() {
        return storebinid;
    }

    /**
     * Définit la valeur de la propriété storebinid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREBINID }
     *     
     */
    public void setSTOREBINID(STOREBINID value) {
        this.storebinid = value;
    }

    /**
     * Obtient la valeur de la propriété forstock.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFORSTOCK() {
        return forstock;
    }

    /**
     * Définit la valeur de la propriété forstock.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFORSTOCK(String value) {
        this.forstock = value;
    }

    /**
     * Obtient la valeur de la propriété forhelditems.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFORHELDITEMS() {
        return forhelditems;
    }

    /**
     * Définit la valeur de la propriété forhelditems.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFORHELDITEMS(String value) {
        this.forhelditems = value;
    }

    /**
     * Obtient la valeur de la propriété outofservice.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Définit la valeur de la propriété outofservice.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/storebin_001/StoreBin.java <==

package net.datastream.schemas.mp_entities.storebin_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STOREBINID;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREBINID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORSTOCK" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORHELDITEMS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "storebinid",
    "forstock",
    "forhelditems",
    "outofservice"
})
@XmlRootElement(name = "StoreBin")
public class StoreBin {

    @XmlElement(name = "STOREBINID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREBINID storebinid;
    @XmlElement(name = "FORSTOCK", namespace = "http://schemas.datastream.net/MP_fields")
    protected String forstock;
    @XmlElement(name = "FORHELDITEMS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String forhelditems;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the storebinid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREBINID }
     *     
     */
    public STOREBINID getSTOREBINID() {
        return storebinid;
    }

    /**
     * Sets the value of the storebinid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREBINID }
     *     
     */
    public void setSTOREBINID(STOREBINID value) {
        this.storebinid = value;
    }

    /**
     * Gets the value of the forstock property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFORSTOCK() {
        return forstock;
    }

    /**
     * Sets the value of the forstock property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFORSTOCK(String value) {
        this.forstock = value;
    }

    /**
     * Gets the value of the forhelditems property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFORHELDITEMS() {
        return forhelditems;
    }

    /**
     * Sets the value of the forhelditems property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFORHELDITEMS(String value) {
        this.forhelditems = value;
    }

    /**
     * Gets the value of the outofservice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Sets the value of the outofservice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
